@@ -185,11 +185,11 @@ def compare_derivatives(func, numerical_derivatives,
                         # This message is useful: the user can see that
                         # tests are really performed (instead of not being
                         # performed, silently):
-                        print "Testing %s at %s, arg #%d" % (
-                            funcname, args, arg_num)
+                        print "Testing derivative #%d of %s at %s" % (
+                            arg_num, funcname, args_scalar)
 
                         if not numbers_close(fixed_deriv_value,
-                                              num_deriv_value, 1e-4):
+                                             num_deriv_value, 1e-4):
 
                             # It is possible that the result is NaN:
                             if not isnan(func_approx):
@@ -554,6 +554,17 @@ def test_pickling():
     assert x_unpickled._nominal_value == 'in slots'
     assert x_unpickled.__dict__ == x.__dict__
 
+    ##
+
+    # Corner case that should have no impact on the code but which is
+    # not prevented by the documentation: case of constant linear
+    # terms (the potential gotcha is that if the linear_combo
+    # attribute is empty, __getstate__()'s result could be false, and
+    # so __setstate__() would not be called and the original empty
+    # linear combination would not be set in linear_combo.
+    x = uncert_core.LinearCombination({})
+    assert pickle.loads(pickle.dumps(x)).linear_combo == {}
+
 def test_int_div():
     "Integer division"
     # We perform all operations on floats, because derivatives can
@@ -1962,14 +1973,31 @@ def test_format():
 
         # More NaN and infinity, in particular with LaTeX and various
         # options:
-        (-float('inf'), float('inf')): {
+        (float('-inf'), float('inf')): {
             'S': '-inf(inf)',
             'LS': '-\infty(\infty)',
             'L': '-\infty \pm \infty',
             'LP': u'-\infty±\infty',
-            # The following is consistent with Python's
-            # "{:020}".format(float("-inf")) ('-0000000000000000inf'):
-            '020S': '-00000000000inf(inf)'
+            # The following is consistent with Python's own
+            # formatting, which depends on the version of Python:
+            # formatting float("-inf") with format(..., "020") gives
+            # '-0000000000000000inf' with Python 2.7, but
+            # '-00000000000000.0inf' with Python 2.6. However, Python
+            # 2.6 gives the better, Python 2.7 form when format()ting
+            # with "020g" instead, so this formatting would be better,
+            # in principle, and similarly for "%020g" % ... Thus,
+            # Python's format() breaks the official rule according to
+            # which no format type is equivalent to "g", for
+            # floats. If the better behavior was needed, internal
+            # formatting could in principle force the "g" formatting
+            # type when none is given; however, Python does not
+            # actually fully treat the none format type in the same
+            # was as the "g" format, so this solution cannot be used,
+            # as it would break other formatting behaviors in this
+            # code. It is thus best to mimic the native behavior of
+            # none type formatting (even if it does not look so good
+            # in Python 2.6).
+            '020S': format(float("-inf"), '015')+'(inf)'
         },
         (-float('nan'), float('inf')): {
             'S': 'nan(inf)',
@@ -2016,7 +2044,8 @@ def test_format():
             # Jython 2.5.2 does not always represent NaN as nan or NAN
             # in the CPython way: for example, '%.2g' % float('nan')
             # is '\ufffd'. The test is skipped, in this case:
-            if jython_detected and isnan(value.std_dev):
+            if jython_detected and (
+                    isnan(value.std_dev) or isnan(value.nominal_value)):
                 continue
 
             # Call that works with Python < 2.6 too:
@@ -2130,7 +2159,7 @@ else:
 
 
     def test_numpy_comparison():
-        "Comparison with a Numpy array."
+        "Comparison with a NumPy array."
 
         x = ufloat(1, 0.1)
 
